@@ -17,7 +17,7 @@ our %EXPORT_TAGS = (
     ':override' => 'internal',
     );
 
-our $VERSION = '1.29_04';
+our $VERSION = '1.29_05';
 
 require DynaLoader;
 {
@@ -33,17 +33,19 @@ my @FULLMON_LIST = qw(January February March April May June July
 my @DAY_LIST = qw(Sun Mon Tue Wed Thu Fri Sat);
 my @FULLDAY_LIST = qw(Sunday Monday Tuesday Wednesday Thursday Friday Saturday);
 
-use constant 'c_sec' => 0;
-use constant 'c_min' => 1;
-use constant 'c_hour' => 2;
-use constant 'c_mday' => 3;
-use constant 'c_mon' => 4;
-use constant 'c_year' => 5;
-use constant 'c_wday' => 6;
-use constant 'c_yday' => 7;
-use constant 'c_isdst' => 8;
-use constant 'c_epoch' => 9;
-use constant 'c_islocal' => 10;
+use constant {
+    'c_sec' => 0,
+    'c_min' => 1,
+    'c_hour' => 2,
+    'c_mday' => 3,
+    'c_mon' => 4,
+    'c_year' => 5,
+    'c_wday' => 6,
+    'c_yday' => 7,
+    'c_isdst' => 8,
+    'c_epoch' => 9,
+    'c_islocal' => 10,
+};
 
 sub localtime {
     unshift @_, __PACKAGE__ unless eval { $_[0]->isa('Time::Piece') };
@@ -84,6 +86,10 @@ sub parse {
     my $proto = shift;
     my $class = ref($proto) || $proto;
     my @components;
+
+    warnings::warnif("deprecated", 
+        "parse() is deprecated, use strptime() instead.");
+
     if (@_ > 1) {
         @components = @_;
     }
@@ -91,7 +97,7 @@ sub parse {
         @components = shift =~ /(\d+)$DATE_SEP(\d+)$DATE_SEP(\d+)(?:(?:T|\s+)(\d+)$TIME_SEP(\d+)(?:$TIME_SEP(\d+)))/;
         @components = reverse(@components[0..5]);
     }
-    return $class->new(_strftime("%s", @components));
+    return $class->new(_strftime("%s", timelocal(@components)));
 }
 
 sub _mktime {
@@ -100,7 +106,9 @@ sub _mktime {
            ? ref $class
            : $class;
     if (ref($time)) {
-        $time->[c_epoch] = undef;
+        my @tm_parts = (@{$time}[c_sec .. c_mon], $time->[c_year]+1900);
+        $time->[c_epoch] = $islocal ? timelocal(@tm_parts) : timegm(@tm_parts);
+
         return wantarray ? @$time : bless [@$time[0..9], $islocal], $class;
     }
     _tzset();
@@ -124,21 +132,21 @@ sub export {
       no warnings 'redefine';
       *{$to . "::$method"} = $_special_exports{$method}->($class);
     } else {
-      $class->SUPER::export($to, $method);
+      $class->Exporter::export($to, $method);
     }
   }
 }
 
 sub import {
-    # replace CORE::GLOBAL localtime and gmtime if required
+    # replace CORE::GLOBAL localtime and gmtime if passed :override
     my $class = shift;
     my %params;
     map($params{$_}++,@_,@EXPORT);
     if (delete $params{':override'}) {
-        $class->Exporter::export('CORE::GLOBAL', keys %params);
+        $class->export('CORE::GLOBAL', keys %params);
     }
     else {
-        $class->Exporter::export(scalar caller, keys %params);
+        $class->export(scalar caller, keys %params);
     }
 }
 
@@ -449,6 +457,9 @@ sub month_last_day {
     return $MON_LAST[$_mon] + ($_mon == 1 ? _is_leap_year($year) : 0);
 }
 
+#since %z and %Z are not portable lets just
+#parse it out before calling native strftime
+#(but only if we are in UTC time)
 my %GMT_REPR = (
     '%z' => '+0000',
     '%Z' => 'UTC',
